=== modified file 'INSTALL'
--- INSTALL	2012-06-29 15:42:14 +0000
+++ INSTALL	2014-06-05 14:01:57 +0000
@@ -1,7 +1,7 @@
 Installation Instructions
 *************************
 
-Copyright (C) 1994-1996, 1999-2002, 2004-2011 Free Software Foundation,
+Copyright (C) 1994-1996, 1999-2002, 2004-2013 Free Software Foundation,
 Inc.
 
    Copying and distribution of this file, with or without modification,
@@ -12,8 +12,8 @@
 Basic Installation
 ==================
 
-   Briefly, the shell commands `./configure; make; make install' should
-configure, build, and install this package.  The following
+   Briefly, the shell command `./configure && make && make install'
+should configure, build, and install this package.  The following
 more-detailed instructions are generic; see the `README' file for
 instructions specific to this package.  Some packages provide this
 `INSTALL' file but do not implement all of the features documented
@@ -309,9 +309,10 @@
 overridden in the site shell script).
 
 Unfortunately, this technique does not work for `CONFIG_SHELL' due to
-an Autoconf bug.  Until the bug is fixed you can use this workaround:
+an Autoconf limitation.  Until the limitation is lifted, you can use
+this workaround:
 
-     CONFIG_SHELL=/bin/bash /bin/bash ./configure CONFIG_SHELL=/bin/bash
+     CONFIG_SHELL=/bin/bash ./configure CONFIG_SHELL=/bin/bash
 
 `configure' Invocation
 ======================
@@ -367,4 +368,3 @@
 
 `configure' also accepts some other, not widely useful, options.  Run
 `configure --help' for more details.
-

=== modified file 'data/package-data-downloader'
--- data/package-data-downloader	2014-04-09 19:23:31 +0000
+++ data/package-data-downloader	2014-06-05 14:01:57 +0000
@@ -165,6 +165,24 @@
         res.append(relfile)
     return res
 
+# we use apt-helper here as this gives us the exact same proxy behavior
+# as apt-get itself (environment/apt-config proxy settings/autodiscover)
+def download_file(uri, sha256_hashsum):
+    """Download a URI and checks the given hashsum using apt-helper
+    
+    Returns: path to the downloaded file or None
+    """
+    download_dir = os.path.join(DATADIR, "partial")
+    dest_file = os.path.join(download_dir, os.path.basename(uri))
+    ret = subprocess.call(
+        ["/usr/lib/apt/apt-helper",
+         "download-file", uri, dest_file, sha256_hashsum])
+    if ret != 0:
+        if os.path.exists(dest_file):
+            os.remove(dest_file)
+        return None
+    return dest_file
+
 def process_download_requests():
     """Process requests to download package data files
 
@@ -179,20 +197,6 @@
     Failed downloads are reported to the user via the
     update-notifier interface."""
 
-    # Get our proxy settings from the environment
-    proxies = {}
-    try:
-        for proto in ('http','https','ftp'):
-            try:
-                proxies[proto] = os.environ[proto+"_proxy"]
-            except KeyError:
-                pass
-
-        if proxies:
-            urllib._urlopener = urllib.FancyURLopener(proxies)
-    except Exception:
-        pass
-
     # Iterate through all the available hooks.  If we get a failure
     # processing any of them (download failure, checksum failure, or
     # failure to run the hook script), record it but continue processing
@@ -236,10 +240,8 @@
                 try:
                     for i in range(len(files)):
                         print("%s: downloading %s" % (relfile, files[i]))
-                        dest_file = urllib.urlretrieve(files[i])[0]
-                        output = subprocess.check_output(["sha256sum", dest_file])
-                        output = output.split(' ')[0]
-                        if output == sums[i]:
+                        dest_file = download_file(files[i][0], sums[i])
+                        if dest_file:
                             command.append(dest_file)
                         else:
                             record_failure(relfile)

=== modified file 'debian/update-notifier-common.dirs'
--- debian/update-notifier-common.dirs	2012-03-20 18:19:10 +0000
+++ debian/update-notifier-common.dirs	2014-06-05 14:01:57 +0000
@@ -3,6 +3,7 @@
 var/lib/update-notifier
 var/lib/update-notifier/user.d
 var/lib/update-notifier/package-data-downloads
+var/lib/update-notifier/package-data-downloads/partial
 etc/update-motd.d
 usr/share/update-notifier/plugins/cache-changed
 usr/share/update-notifier/upgrader-patches

=== modified file 'tests/test_package-data-downloader.py'
--- tests/test_package-data-downloader.py	2012-10-09 20:59:08 +0000
+++ tests/test_package-data-downloader.py	2014-06-05 14:01:57 +0000
@@ -1,14 +1,61 @@
 #!/usr/bin/python
 
+import hashlib
+from multiprocessing.process import Process
 import os
+import random
+import SimpleHTTPServer
 import shutil
+import SocketServer
 import sys
 import tempfile
 import unittest
 
+
 sys.path.insert(0, "../data")
 import package_data_downloader
 
+
+class TestHttpd(Process):
+    def __init__(self, port, servdir):
+        super(TestHttpd, self).__init__()
+        self.port = port
+        self.servdir = servdir
+    def run(self):
+        os.chdir(self.servdir)
+        Handler = SimpleHTTPServer.SimpleHTTPRequestHandler
+        httpd = SocketServer.TCPServer(("localhost", self.port), Handler)
+        httpd.serve_forever()
+
+
+class DownloadTestCase(unittest.TestCase):
+
+    def setUp(self):
+        self.tempdir = tempfile.mkdtemp()
+        self._setup_canary_file()
+        self.PORT = random.randint(1025, 60000)
+        self.p = TestHttpd(self.PORT, self.tempdir)
+        self.p.start()
+    def tearDown(self):
+        self.p.terminate()
+        shutil.rmtree(self.tempdir)
+    def _setup_canary_file(self):
+        self.canary_text = "meep"
+        self.canary_file = os.path.join(self.tempdir, "canary-file.txt")
+        with open(self.canary_file, "w") as f:
+            f.write(self.canary_text)
+        self.canary_hashsum = hashlib.sha256(self.canary_text).hexdigest()
+    def test_download_file(self):
+        package_data_downloader.DATADIR = self.tempdir
+        os.makedirs(os.path.join(self.tempdir, "partial"))
+        uri = "http://localhost:%s/%s" % (
+            self.PORT, os.path.basename(self.canary_file))
+        destfile = package_data_downloader.download_file(
+            uri, "SHA256:"+self.canary_hashsum)
+        self.assertNotEqual(destfile, None)
+        self.assertEqual(hashlib.sha256(open(destfile).read()).hexdigest(),
+                         self.canary_hashsum)
+
 class PackageDataDownloaderTestCase(unittest.TestCase):
 
     def setUp(self):

